pub struct Status { /* private fields */ }Expand description
The status of the floating point context. Instead of faulting after every operation errors are added to this status. User code can check and/or clear the status fully or partially at specific points to check the validity of the computation. Each thread gets its own status. The status is initially empty.
Examples
assert_eq!(d128::get_status(), Status::empty());
let _ = d128!(1) / &d128!(0);
assert!(d128::get_status().contains(decimal::Status::DIVISION_BY_ZERO));
let _ = d128!(0) / &d128!(0);
assert!(d128::get_status().contains(decimal::Status::DIVISION_UNDEFINED));
// The previous status flag was not cleared!
assert!(d128::get_status().contains(decimal::Status::DIVISION_BY_ZERO));Implementations
Sourceimpl Status
impl Status
Sourcepub const CONVERSION_SYNTAX: Status
pub const CONVERSION_SYNTAX: Status
Conversion syntax error.
Sourcepub const DIVISION_BY_ZERO: Status
pub const DIVISION_BY_ZERO: Status
Division by zero.
Sourcepub const DIVISION_IMPOSSIBLE: Status
pub const DIVISION_IMPOSSIBLE: Status
Division impossible.
Sourcepub const DIVISION_UNDEFINED: Status
pub const DIVISION_UNDEFINED: Status
Division undefined.
Sourcepub const INVALID_OPERATION: Status
pub const INVALID_OPERATION: Status
An invalid operation was requested.
Sourcepub const fn from_bits(bits: u32) -> Option<Status>
pub const fn from_bits(bits: u32) -> Option<Status>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> Status
pub const fn from_bits_truncate(bits: u32) -> Status
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Status
pub const unsafe fn from_bits_unchecked(bits: u32) -> Status
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Status) -> bool
pub const fn intersects(&self, other: Status) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Status) -> bool
pub const fn contains(&self, other: Status) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Status, value: bool)
pub fn set(&mut self, other: Status, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Status) -> Status
pub const fn intersection(self, other: Status) -> Status
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Status) -> Status
pub const fn union(self, other: Status) -> Status
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Status) -> Status
pub const fn difference(self, other: Status) -> Status
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Status) -> Status
pub const fn symmetric_difference(self, other: Status) -> Status
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Status
pub const fn complement(self) -> Status
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.